==> knative-model-4.9.2-sources.jar: io/fabric8/knative/messaging/v1alpha1/InMemoryChannelFluentImpl.java <==
package io.fabric8.knative.messaging.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Object;

public class InMemoryChannelFluentImpl<A extends InMemoryChannelFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements InMemoryChannelFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private InMemoryChannelSpecBuilder spec;
    private InMemoryChannelStatusBuilder status;

    public InMemoryChannelFluentImpl(){
    }
    public InMemoryChannelFluentImpl(InMemoryChannel instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.get("metadata").remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public InMemoryChannelFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public InMemoryChannelFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public InMemoryChannelFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public InMemoryChannelFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public InMemoryChannelFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public InMemoryChannelSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public InMemoryChannelSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(InMemoryChannelSpec spec){
            _visitables.get("spec").remove(this.spec);
            if (spec!=null){ this.spec= new InMemoryChannelSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public InMemoryChannelFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public InMemoryChannelFluent.SpecNested<A> withNewSpecLike(InMemoryChannelSpec item){
            return new SpecNestedImpl(item);
    }

    public InMemoryChannelFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public InMemoryChannelFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new InMemoryChannelSpecBuilder().build());
    }

    public InMemoryChannelFluent.SpecNested<A> editOrNewSpecLike(InMemoryChannelSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public InMemoryChannelStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public InMemoryChannelStatus buildStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(InMemoryChannelStatus status){
            _visitables.get("status").remove(this.status);
            if (status!=null){ this.status= new InMemoryChannelStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public InMemoryChannelFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public InMemoryChannelFluent.StatusNested<A> withNewStatusLike(InMemoryChannelStatus item){
            return new StatusNestedImpl(item);
    }

    public InMemoryChannelFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public InMemoryChannelFluent.StatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new InMemoryChannelStatusBuilder().build());
    }

    public InMemoryChannelFluent.StatusNested<A> editOrNewStatusLike(InMemoryChannelStatus item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            InMemoryChannelFluentImpl that = (InMemoryChannelFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<InMemoryChannelFluent.MetadataNested<N>> implements InMemoryChannelFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) InMemoryChannelFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends InMemoryChannelSpecFluentImpl<InMemoryChannelFluent.SpecNested<N>> implements InMemoryChannelFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final InMemoryChannelSpecBuilder builder;
    
            SpecNestedImpl(InMemoryChannelSpec item){
                    this.builder = new InMemoryChannelSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new InMemoryChannelSpecBuilder(this);
            }
    
    public N and(){
            return (N) InMemoryChannelFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}
    public class StatusNestedImpl<N> extends InMemoryChannelStatusFluentImpl<InMemoryChannelFluent.StatusNested<N>> implements InMemoryChannelFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final InMemoryChannelStatusBuilder builder;
    
            StatusNestedImpl(InMemoryChannelStatus item){
                    this.builder = new InMemoryChannelStatusBuilder(this, item);
            }
            StatusNestedImpl(){
                    this.builder = new InMemoryChannelStatusBuilder(this);
            }
    
    public N and(){
            return (N) InMemoryChannelFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}

==> knative-model-4.11.0-sources.jar: io/fabric8/knative/messaging/v1alpha1/InMemoryChannelFluentImpl.java <==
package io.fabric8.knative.messaging.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Object;

public class InMemoryChannelFluentImpl<A extends InMemoryChannelFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements InMemoryChannelFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private InMemoryChannelSpecBuilder spec;
    private InMemoryChannelStatusBuilder status;

    public InMemoryChannelFluentImpl(){
    }
    public InMemoryChannelFluentImpl(InMemoryChannel instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.get("metadata").remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public InMemoryChannelFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public InMemoryChannelFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public InMemoryChannelFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public InMemoryChannelFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public InMemoryChannelFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public InMemoryChannelSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public InMemoryChannelSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(InMemoryChannelSpec spec){
            _visitables.get("spec").remove(this.spec);
            if (spec!=null){ this.spec= new InMemoryChannelSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public InMemoryChannelFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public InMemoryChannelFluent.SpecNested<A> withNewSpecLike(InMemoryChannelSpec item){
            return new SpecNestedImpl(item);
    }

    public InMemoryChannelFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public InMemoryChannelFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new InMemoryChannelSpecBuilder().build());
    }

    public InMemoryChannelFluent.SpecNested<A> editOrNewSpecLike(InMemoryChannelSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public InMemoryChannelStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public InMemoryChannelStatus buildStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(InMemoryChannelStatus status){
            _visitables.get("status").remove(this.status);
            if (status!=null){ this.status= new InMemoryChannelStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public InMemoryChannelFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public InMemoryChannelFluent.StatusNested<A> withNewStatusLike(InMemoryChannelStatus item){
            return new StatusNestedImpl(item);
    }

    public InMemoryChannelFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public InMemoryChannelFluent.StatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new InMemoryChannelStatusBuilder().build());
    }

    public InMemoryChannelFluent.StatusNested<A> editOrNewStatusLike(InMemoryChannelStatus item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            InMemoryChannelFluentImpl that = (InMemoryChannelFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<InMemoryChannelFluent.MetadataNested<N>> implements InMemoryChannelFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) InMemoryChannelFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends InMemoryChannelSpecFluentImpl<InMemoryChannelFluent.SpecNested<N>> implements InMemoryChannelFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final InMemoryChannelSpecBuilder builder;
    
            SpecNestedImpl(InMemoryChannelSpec item){
                    this.builder = new InMemoryChannelSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new InMemoryChannelSpecBuilder(this);
            }
    
    public N and(){
            return (N) InMemoryChannelFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}
    public class StatusNestedImpl<N> extends InMemoryChannelStatusFluentImpl<InMemoryChannelFluent.StatusNested<N>> implements InMemoryChannelFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final InMemoryChannelStatusBuilder builder;
    
            StatusNestedImpl(InMemoryChannelStatus item){
                    this.builder = new InMemoryChannelStatusBuilder(this, item);
            }
            StatusNestedImpl(){
                    this.builder = new InMemoryChannelStatusBuilder(this);
            }
    
    public N and(){
            return (N) InMemoryChannelFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}
